Learn R Programming

brglm (version 0.5-2)

profile.brglm: Calculate profiles for objects of class 'brglm'.

Description

Creates "profile.brglm" objects to be used for the calculation of confidence intervals and for plotting.

Usage

## S3 method for class 'brglm':
profile(fitted, gridsize = 10, stdn = 5,
        stepsize = 0.5, level = 0.95,
        which = 1:length(coef(fitted)), verbose = TRUE,
        zero.bound = 1e-08, scale = FALSE, ...)

Arguments

fitted
an object of class "brglm".
gridsize
stdn
stepsize
level
qchisq(level,1) indicates the range that the profiles must cover.
which
verbose
zero.bound
scale
...
further arguments passed to or from other methods.

Value

  • An object of class "profile.glm" with attribute level corresponding to the argument level. The object supports the methods print, plot, pairs and confint and it is a list of the components:
  • profilesMLa "profileModel" object containing the profiles of the ordinary deviance for the maximum likelihood fit corresponding to fitted.
  • profilesBRNULL if method = "glm.fit" in brglm. If method = "brglm.fit" and pl = TRUE, profilesBR is a "profileModel" object containing the profiles of the penalized deviance for the parameters of fitted. If method = "brglm.fit" and pl = FALSE profilesBR is a "profileModel" object containing the profiles of the modified score statistic (see profileObjectives) for the parameters of fitted.

Details

profile.brglm calculates the profiles of the appropriate objectives to be used for the construction of confidence intervals for the bias-reduced estimates (see confint.brglm for the objectives that are profiled).

See Also

profileModel, profile.brglm.

Examples

Run this code
# see example in 'confint.brglm'.

Run the code above in your browser using DataLab