profile.brglmpenalizedDeviance(fm, X, dispersion = 1)modifiedScoreStatistic(fm, X, dispersion = 1)
profile.brglm. penalizedDeviance returns a deviance-like value corresponding
to a likelihood function penalized by Jeffreys invariant prior. It
has been used by Heinze & Schemper (2002) and by Bull et. al. (2002)
for the construction of confidence intervals for the bias-reduced
estimates in logistic regression. The X argument is the
model matrix of the full (not the restricted) fit.
modifiedScoreStatistic mimics RaoScoreStatistic
in X has
the same interpretation as for penalizedDeviance.
Heinze, G. and Schemper, M. (2002). A solution to the problem of separation in logistic regression. Statistics in Medicine 21, 2409--2419.
profileModel, profile.brglm.